==> openedx-filters-1.0.0.tar.gz: openedx-filters-1.0.0/setup.py <==
#!/usr/bin/env python
"""
Package metadata for openedx_filters.
"""
import os
import re
import sys

from setuptools import setup


def get_version(*file_paths):
    """
    Extract the version string from the file.

    Input:
     - file_paths: relative path fragments to file with
                   version string
    """
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()  # pylint: disable=consider-using-with
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


def load_requirements(*requirements_paths):
    """
    Load all requirements from the specified requirements files.

    Returns:
        list: Requirements file relative path strings
    """
    requirements = set()
    for path in requirements_paths:
        with open(path) as file:
            requirements.update(
                line.split('#')[0].strip() for line in file.readlines()
                if is_requirement(line.strip())
            )
    return list(requirements)


def is_requirement(line):
    """
    Return True if the requirement line is a package requirement.

    Returns:
        bool: True if the line is not blank, a comment, a URL, or
              an included file
    """
    return line and not line.startswith(("-r", "#", "-e", "git+", "-c"))


VERSION = get_version("openedx_filters", "__init__.py")

if sys.argv[-1] == "tag":
    print("Tagging the version on github:")
    os.system("git tag -a %s -m 'version %s'" % (VERSION, VERSION))
    os.system("git push --tags")
    sys.exit()

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()
with open(os.path.join(os.path.dirname(__file__), 'CHANGELOG.rst')) as changelog:
    CHANGELOG = changelog.read()

setup(
    name="openedx-filters",
    version=VERSION,
    description="""Open edX Filters from Hooks Extensions Framework (OEP-50).""",
    long_description=README + "\n\n" + CHANGELOG,
    long_description_content_type='text/x-rst',
    author="eduNEXT",
    author_email="technical@edunext.co",
    url="https://github.com/openedx/openedx-filters",
    packages=[
        "openedx_filters",
    ],
    include_package_data=True,
    install_requires=load_requirements("requirements/base.in"),
    python_requires=">=3.8",
    license="AGPL 3.0",
    zip_safe=False,
    keywords="Python openedx",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
    ],
)

==> openedx-filters-1.6.0.tar.gz: openedx-filters-1.6.0/setup.py <==
#!/usr/bin/env python
"""
Package metadata for openedx_filters.
"""
import os
import re
import sys

from setuptools import setup


def get_version(*file_paths):
    """
    Extract the version string from the file.

    Input:
     - file_paths: relative path fragments to file with
                   version string
    """
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()  # pylint: disable=consider-using-with
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


def load_requirements(*requirements_paths):
    """
    Load all requirements from the specified requirements files.

    Returns:
        list: Requirements file relative path strings
    """
    requirements = set()
    for path in requirements_paths:
        with open(path) as file:
            requirements.update(
                line.split('#')[0].strip() for line in file.readlines()
                if is_requirement(line.strip())
            )
    return list(requirements)


def is_requirement(line):
    """
    Return True if the requirement line is a package requirement.

    Returns:
        bool: True if the line is not blank, a comment, a URL, or
              an included file
    """
    return line and not line.startswith(("-r", "#", "-e", "git+", "-c"))


VERSION = get_version("openedx_filters", "__init__.py")

if sys.argv[-1] == "tag":
    print("Tagging the version on github:")
    os.system("git tag -a %s -m 'version %s'" % (VERSION, VERSION))
    os.system("git push --tags")
    sys.exit()

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()
with open(os.path.join(os.path.dirname(__file__), 'CHANGELOG.rst')) as changelog:
    CHANGELOG = changelog.read()

setup(
    name="openedx-filters",
    version=VERSION,
    description="""Open edX Filters from Hooks Extensions Framework (OEP-50).""",
    long_description=README,
    long_description_content_type='text/x-rst',
    author="eduNEXT",
    author_email="technical@edunext.co",
    url="https://github.com/openedx/openedx-filters",
    packages=[
        "openedx_filters",
    ],
    include_package_data=True,
    install_requires=load_requirements("requirements/base.in"),
    python_requires=">=3.8",
    license="AGPL 3.0",
    zip_safe=False,
    keywords="Python openedx",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
    ],
)
